@@ -20,17 +20,6 @@ import platform
 
 from pcm.func import _login, _edm, _setupfiles, _code, _launcher, _init
 
-IS_MAC = platform.system() == "Darwin"
-IS_WINDOWS = platform.system() == "Windows"
-HOME = os.path.expanduser("~")
-EDM_ENVS_ROOT = os.path.join(HOME, ".edm", "envs")
-EDM_BIN = os.path.join(EDM_ENVS_ROOT, "edm", "bin")
-
-if IS_WINDOWS:
-    GIT = "C:\\Git\\bin\\git"
-else:
-    GIT = "git"
-
 
 @click.group()
 def cli():
