@@ -18,12 +18,24 @@
 import os
 import shutil
 import subprocess
+import platform
 
 import click
 import yaml
 
 from pcm import util, requirements, render
-from pcm.cli import HOME, GIT, IS_MAC, EDM_ENVS_ROOT
+
+IS_MAC = platform.system() == "Darwin"
+IS_WINDOWS = platform.system() == "Windows"
+HOME = os.path.expanduser("~")
+EDM_ENVS_ROOT = os.path.join(HOME, ".edm", "envs")
+EDM_BIN = os.path.join(EDM_ENVS_ROOT, "edm", "bin")
+
+
+if IS_WINDOWS:
+    GIT = "C:\\Git\\bin\\git"
+else:
+    GIT = "git"
 
 
 def _login(env, app_id):
@@ -142,8 +154,7 @@ def _code(fork, branch, app_id):
         if not util.yes(
             "Pychron source code already exists. Remove and re-clone [y]/n"
         ):
-            subprocess.call(["cd", ppath])
-            subprocess.call([GIT, "status"])
+            subprocess.call([GIT, "status"], cwd=ppath)
             return
 
         shutil.rmtree(ppath)
@@ -151,8 +162,7 @@ def _code(fork, branch, app_id):
     url = f"https://github.com/{fork}/pychron.git"
 
     subprocess.call([GIT, "clone", url, f"--branch={branch}", ppath])
-    subprocess.call(["cd", ppath])
-    subprocess.call([GIT, "status"])
+    subprocess.call([GIT, "status"], cwd=ppath)
 
 
 def _launcher(
@@ -190,7 +200,7 @@ def _launcher(
 
 def _init(env, org, overwrite, verbose):
     click.echo("make initialization file")
-    template = "initialization.xml"
+    template = "initialization.xml.template"
     txt = render.render_template(template)
     if verbose:
         click.echo("======== Initialization.xml contents start ========")
@@ -225,10 +235,9 @@ def _init(env, org, overwrite, verbose):
     util.write(p, txt, overwrite=overwrite)
 
     template = "arar_constants.ini.template"
-    txt = render.render_template(
-        template
-    )
+    txt = render.render_template(template)
     p = os.path.join(d, "arar_constants.ini")
     util.write(p, txt, overwrite=overwrite)
 
+
 # ============= EOF =============================================
