@@ -46,6 +46,7 @@ EDM_REQUIREMENTS = [
     "xlrd",
     "xlsxwriter",
     "xlwt",
-    "statsmodels"
+    "statsmodels",
+    "utm",
 ]
 # ============= EOF =============================================
